@@ -1,5 +1,5 @@
 (* libguestfs
- * Copyright (C) 2009-2023 Red Hat Inc.
+ * Copyright (C) 2009-2025 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -347,14 +347,6 @@ Run it from the top source directory using the command
   output_to "gobject/src/session.c"
             GObject.generate_gobject_session_source;
 
-  (* mlv2v may not be shipped in this source. *)
-  if is_regular_file "common/mlv2v/Makefile.am" then (
-    output_to "common/mlv2v/uefi.ml"
-              UEFI.generate_uefi_ml;
-    output_to "common/mlv2v/uefi.mli"
-              UEFI.generate_uefi_mli;
-  );
-
   (* mlcustomize may not be shipped in this source. *)
   if is_regular_file "common/mlcustomize/Makefile.am" then (
     output_to "common/mlcustomize/customize_cmdline.mli"
